# AppKit MCP User Server

MCP server for querying user analytics data via natural language.

## Features

- **Query Users**: Natural language interface to `auth_users` table
- **Security**: Built-in SQL validation and role-based column filtering
- **Authentication**: Session-based auth via AppKit user session
